@@ -10,7 +10,7 @@ class Flask():
     def __init__(self, app):
         self.app = app
         self.route = '/nodecdn.js'
-        return self
+        return app
         
     def change_path(self, path):
         self.route = path
